@@ -124,23 +124,13 @@ init (CamelFolder *folder)
 		CAMEL_MESSAGE_JUNK | CAMEL_MESSAGE_USER;
 }
 
-static void
-free_index_and_mid (gpointer thread_index, gpointer message_id, gpointer d)
-{
-	g_free (thread_index);
-	g_free (message_id);
-}
-
 static void
 finalize (CamelExchangeFolder *exch)
 {
 	camel_object_unref (CAMEL_OBJECT (exch->cache));
 
-	if (exch->thread_index_to_message_id) {
-		g_hash_table_foreach (exch->thread_index_to_message_id,
-				      free_index_and_mid, NULL);
+	if (exch->thread_index_to_message_id)
 		g_hash_table_destroy (exch->thread_index_to_message_id);
-	}
 	g_free (exch->source);
 }
 
@@ -256,7 +246,7 @@ append_message (CamelFolder *folder, CamelMimeMessage *message,
 {
 	CamelStream *stream_mem;
 	CamelExchangeStore *store = CAMEL_EXCHANGE_STORE (folder->parent_store);
-
+	GByteArray *mem_bytes;
 	gchar *old_subject = NULL;
 	GString *new_subject;
 	gint i, len;
@@ -288,12 +278,13 @@ append_message (CamelFolder *folder, CamelMimeMessage *message,
 		camel_exchange_journal_append ((CamelExchangeJournal *) ((CamelExchangeFolder *)folder)->journal, message, info, appended_uid, ex);
 		return;
 	}
-	stream_mem = camel_stream_mem_new ();
+	mem_bytes = g_byte_array_new ();
+	stream_mem = camel_stream_mem_new_with_byte_array (mem_bytes);
 	camel_data_wrapper_write_to_stream (CAMEL_DATA_WRAPPER (message),
 					    stream_mem);
 	camel_stream_flush (stream_mem);
 
-	append_message_data (folder, CAMEL_STREAM_MEM (stream_mem)->buffer,
+	append_message_data (folder, mem_bytes,
 			     camel_mime_message_get_subject (message),
 			     info, appended_uid, ex);
 
@@ -423,6 +414,21 @@ get_message (CamelFolder *folder, const gchar *uid, CamelException *ex)
 	if (!ba)
 		return NULL;
 
+	while ((ba->len > 10 && g_str_has_prefix ((const gchar *)ba->data, "MAIL FROM:")) ||
+	       (ba->len >  8 && g_str_has_prefix ((const gchar *)ba->data, "RCPT TO:")) ||
+	       (ba->len >  2 && (ba->data[0] == '\n' || ba->data[1] == '\n'))) {
+		guint i;
+
+		i = 0;
+		while (i < ba->len && ba->data[i] != '\n')
+			i++;
+
+		if (i < ba->len)
+			g_byte_array_remove_range (ba, 0, i + 1);
+		else
+			break;
+	}
+
 	stream = camel_stream_mem_new_with_byte_array (ba);
 
 	crlffilter = camel_mime_filter_crlf_new (CAMEL_MIME_FILTER_CRLF_DECODE, CAMEL_MIME_FILTER_CRLF_MODE_CRLF_ONLY);
@@ -803,8 +809,6 @@ camel_exchange_folder_remove_message (CamelExchangeFolder *exch,
 						  einfo->thread_index,
 						  &key, &value)) {
 			g_hash_table_remove (exch->thread_index_to_message_id, key);
-			g_free (key);
-			g_free (value);
 		}
 	}
 
@@ -1018,7 +1022,7 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 	camel_object_state_read (folder);
 
 	exch->thread_index_to_message_id =
-		g_hash_table_new (g_str_hash, g_str_equal);
+		g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
 	len = camel_folder_summary_count (folder->summary);
 	for (i = 0; i < len; i++) {
@@ -1049,7 +1053,7 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 			camel_folder_summary_reload_from_db (folder->summary, ex);
 
 		for (i = 0; i < summary->len; i++) {
-			uids->pdata[i] = g_strdup(summary->pdata[i]);
+			uids->pdata[i] = summary->pdata[i];
 			info = camel_folder_summary_uid (folder->summary, uids->pdata[i]);
 			flags->data[i] = ((CamelMessageInfoBase *)info)->flags & CAMEL_EXCHANGE_SERVER_FLAGS;
 			hrefs->pdata[i] = ((CamelExchangeMessageInfo *)info)->href;
