@@ -3,19 +3,13 @@
 
 /* camel-exchange-store.h: class for a exchange store */
 
-
 #ifndef CAMEL_EXCHANGE_STORE_H
 #define CAMEL_EXCHANGE_STORE_H 1
 
-
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #include <camel/camel-store.h>
 #include <camel/camel-offline-store.h>
-#include "camel-stub.h"
 
 #define CAMEL_EXCHANGE_STORE_TYPE     (camel_exchange_store_get_type ())
 #define CAMEL_EXCHANGE_STORE(obj)     (CAMEL_CHECK_CAST((obj), CAMEL_EXCHANGE_STORE_TYPE, CamelExchangeStore))
@@ -25,13 +19,11 @@ extern "C" {
 typedef struct {
 	CamelOfflineStore parent_object;
 
-	CamelStub *stub;
-	char *storage_path, *base_url;
-	char *trash_name;
+	gchar *storage_path, *base_url;
+	gchar *trash_name;
 	GHashTable *folders;
 	GMutex *folders_lock;
 
-	gboolean stub_connected;
 	GMutex *connect_lock;
 
 } CamelExchangeStore;
@@ -41,14 +33,14 @@ typedef struct {
 
 } CamelExchangeStoreClass;
 
-
 /* Standard Camel function */
 CamelType camel_exchange_store_get_type (void);
 
 gboolean camel_exchange_store_connected (CamelExchangeStore *store, CamelException *ex);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+void camel_exchange_store_folder_created (CamelExchangeStore *estore, const gchar *name, const gchar *uri);
+void camel_exchange_store_folder_deleted (CamelExchangeStore *estore, const gchar *name, const gchar *uri);
+
+G_END_DECLS
 
 #endif /* CAMEL_EXCHANGE_STORE_H */
